"use strict";
/**
 * @format
 * @flow
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Chip = void 0;
const react_1 = __importDefault(require("react"));
const react_native_paper_1 = require("react-native-paper");
const Icon_1 = require("../Icon");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const Chip = (props) => {
    const { children, icon, iconColor, style, textStyle, mode = 'outlined', selected, disabled, avatar, chipColor, borderColor, textColor, theme: themeOverride, ...rest } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride);
    const isOutlined = mode === 'outlined';
    const isElevated = mode === 'elevated';
    const defaultChipColor = isOutlined
        ? disabled
            ? //the chip background color should be transparent in case it is set to disable in outline mode
                'transparent'
            : selected
                ? //the chip background color should be primary[80] in case it is set to selected in outline mode
                    theme.colors.primaryContainer
                : //the chip background color should be transparent in case it is set to unselected in outline mode
                    'transparent'
        : disabled
            ? //the chip background color should be neutral[10] 5% in case it is set to disable in elevated mode
                theme.colors.disabledContainer
            : selected
                ? //the chip background color should be primary[80] in case it is set to selected in elevated mode
                    theme.colors.primaryContainer
                : //the chip background color should be neutral[97] in case it is set to unselected in elevated mode
                    theme.colors.surfaceContainerLow;
    const DefaultTextColor = isOutlined
        ? disabled
            ? //the chip text color should be neutral[10] 20% in case it is set to disable in outline mode
                theme.colors.disabled
            : selected
                ? //the chip text color should be primary[80] in case it is set to selected in outline mode
                    theme.colors.onPrimaryContainer
                : //the chip text color should be neutralVariant[30] in case it is set to unselected in outline mode
                    theme.colors.onSurfaceVariant
        : disabled
            ? //the chip text color should be neutral[10] 25% in case it is set to disable in elevated mode
                theme.colors.onDisabledContainer
            : selected
                ? //the chip text color should be BLUIColors.primary[30] in case it is set to selected in elevated mode
                    theme.colors.onPrimaryContainer
                : //the chip text color should be neutralVariant[30] in case it is set to unselected in elevated mode
                    theme.colors.onSurfaceVariant;
    const getIcon = () => {
        if (icon) {
            return (react_1.default.createElement(Icon_1.Icon, { source: icon, size: 18, color: iconColor ? iconColor : textColor ? textColor : DefaultTextColor }));
        }
        else if (avatar) {
            return avatar; // Show the passed Avatar component
        }
        return undefined;
    };
    const chipStyle = isElevated
        ? {}
        : selected
            ? {}
            : {
                borderWidth: 1,
                borderColor: borderColor ? borderColor : disabled ? theme.colors.disabled : theme.colors.outline,
            };
    const renderCloseIcon = () => react_1.default.createElement(Icon_1.Icon, { source: { name: 'close' }, size: 18, color: DefaultTextColor });
    const renderIcon = () => getIcon();
    return (react_1.default.createElement(react_1.default.Fragment, null, icon ? (react_1.default.createElement(react_native_paper_1.Chip, { style: [
            {
                backgroundColor: chipColor ? chipColor : defaultChipColor,
            },
            style,
            chipStyle,
        ], textStyle: [
            { color: textColor ? textColor : DefaultTextColor, fontFamily: 'OpenSans-Regular' },
            textStyle,
        ], showSelectedCheck: false, selected: selected, disabled: disabled, ...(isElevated && { elevated: !disabled }), closeIcon: renderCloseIcon, icon: renderIcon, ...rest }, children)) : avatar ? (react_1.default.createElement(react_native_paper_1.Chip, { style: [
            {
                backgroundColor: chipColor ? chipColor : defaultChipColor,
            },
            style,
            chipStyle,
        ], textStyle: [
            { color: textColor ? textColor : DefaultTextColor, fontFamily: 'OpenSans-Regular' },
            textStyle,
        ], showSelectedCheck: false, selected: selected, disabled: disabled, avatar: avatar, ...(isElevated && { elevated: !disabled }), closeIcon: renderCloseIcon, ...rest }, children)) : (react_1.default.createElement(react_native_paper_1.Chip, { style: [
            {
                backgroundColor: chipColor ? chipColor : defaultChipColor,
            },
            style,
            chipStyle,
        ], textStyle: [
            { color: textColor ? textColor : DefaultTextColor, fontFamily: 'OpenSans-Regular' },
            textStyle,
        ], showSelectedCheck: false, selected: selected, disabled: disabled, ...(isElevated && { elevated: !disabled }), closeIcon: renderCloseIcon, ...rest }, children))));
};
exports.Chip = Chip;
